@@ -21,8 +21,6 @@ use Tie::IxHash;
 use WebGUI::Utility;
 use WebGUI::International;
 use JSON qw/from_json to_json/;
-use Storable qw/dclone/;
-use Data::Dumper;
 
 =head1 NAME
 
@@ -70,15 +68,8 @@ sub addRevision {
     my $session = $self->session;
     my $newSelf = $self->next::method(@_);
 
-    my $newProperties = {
-        isHidden => 1,
-    };
-
-    $newSelf->update($newProperties);
-
     my $newPhotoData = $newSelf->duplicatePhotoData;
     $newSelf->setPhotoData($newPhotoData);
-    #$newSelf->requestAutoCommit;
 
     return $newSelf;
 }
@@ -516,12 +507,10 @@ Returns the photo hash formatted as perl data.  See also L<setPhotoData>.
 
 sub getPhotoData {
 	my $self     = shift;
-	if (!exists $self->{_photoData}) {
-        my $json = $self->get('photo');
-        $json ||= '[]';
-        $self->{_photoData} = from_json($json);
-	}
-	return dclone($self->{_photoData});
+    my $json = $self->get('photo');
+    $json ||= '[]';
+    my $photoData = from_json($json);
+	return $photoData;
 }
 
 #-------------------------------------------------------------------
@@ -602,8 +591,6 @@ sub processPropertiesFromFormPost {
     my $session = $self->session;
     $self->next::method;
     my $archive = delete $self->{_parent};  ##Force a new lookup.
-    #$session->log->warn($self->getParent->get('className'));
-    #$session->log->warn($self->getParent->getParent->get('className'));
     my $form    = $session->form;
     ##Handle old data first, to avoid iterating across a newly added photo.
     my $photoData      = $self->getPhotoData;
@@ -758,7 +745,6 @@ sub setPhotoData {
     my $photo     = to_json($photoData);
     ##Update the db.
     $self->update({photo => $photo});
-    delete $self->{_photoData};
     return;
 }
 
@@ -819,7 +805,6 @@ Extend the superclass to make sure that the asset always stays hidden from navig
 sub update {
     my $self   = shift;
     my $properties = shift;
-    #$self->session->log->warn('story update');
     return $self->next::method({%$properties, isHidden => 1});
 }
 
