@@ -240,6 +240,7 @@ sub paymentVariables {
     my $url  = $self->session->url;
     my $base = $url->getSiteURL . $url->page;
     my $cart = $self->getCart;
+    my $i18n = WebGUI::International->new($self->session);
 
     my $return = URI->new($base);
     $return->query_form( {
@@ -262,10 +263,11 @@ sub paymentVariables {
 
         return        => $return->as_string,
         cancel_return => $cancel->as_string,
+        lc            => $i18n->getLanguage->{locale},
 
         handling_cart        => $cart->calculateShipping,  ##According to https://www.x.com/message/180018#180018
         tax_cart             => $cart->calculateTaxes,
-        discount_amount_cart => -($cart->calculateShopCreditDeduction),
+        discount_amount_cart => abs($cart->calculateShopCreditDeduction),
 
         # When we verify that we have a valid transaction ID later on in
         # processPayment, we'll make sure it's the cart we think it is.
