@@ -778,8 +778,8 @@ our $I18N = {
     'message' => 'Standaard Thingy'
   },
   'viewScreenTitle' => {
-    'lastUpdated' => '1205854475',
-    'message' => 'De titel voor het weergave scherm'
+    'lastUpdated' => '1302256493',
+    'message' => 'De titel voor het weergave scherm. Dit is een aaneensluiting van alle waarden van velden die de titel van het weergave scherm ingesteld hebben voor dit Thing. Als er geen velden ingesteld zijn, is dit veld leeg.'
   },
   'view_url' => {
     'lastUpdated' => '1228763556',
